/*
 * Copyright 2019 Louis Lenders
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA
 */

import "oaidl.idl";

[
    object,
    uuid(82ba7092-4c88-427d-a7bc-16dd93feb67e),
    pointer_default(unique)
]
interface IRestrictedErrorInfo : IUnknown
{
    HRESULT GetErrorDetails (
        [out] BSTR *desc,
        [out] HRESULT *error,
        [out] BSTR *restricted_desc,
        [out] BSTR *sid);

    HRESULT GetReference ([out] BSTR *reference);
}
